@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 module Rouge
   module Lexers
@@ -7,7 +8,7 @@ module Rouge
       desc "Dockerfile syntax"
       tag 'docker'
       aliases 'dockerfile'
-      filenames 'Dockerfile', '*.docker'
+      filenames 'Dockerfile', '*.Dockerfile', '*.docker'
       mimetypes 'text/x-dockerfile-config'
 
       KEYWORDS = %w(
@@ -17,32 +18,32 @@ module Rouge
       start { @shell = Shell.new(@options) }
 
       state :root do
-        rule /\s+/, Text
+        rule %r/\s+/, Text
 
-        rule /^(ONBUILD)(\s+)(#{KEYWORDS})(.*)/io do |m|
+        rule %r/^(ONBUILD)(\s+)(#{KEYWORDS})(.*)/io do
           groups Keyword, Text::Whitespace, Keyword, Str
         end
 
-        rule /^(#{KEYWORDS})\b(.*)/io do |m|
+        rule %r/^(#{KEYWORDS})\b(.*)/io do
           groups Keyword, Str
         end
 
-        rule /#.*?$/, Comment
+        rule %r/#.*?$/, Comment
 
-        rule /^(ONBUILD\s+)?RUN(\s+)/i do
+        rule %r/^(ONBUILD\s+)?RUN(\s+)/i do
           token Keyword
           push :run
           @shell.reset!
         end
 
-        rule /\w+/, Text
-        rule /[^\w]+/, Text
-        rule /./, Text
+        rule %r/\w+/, Text
+        rule %r/[^\w]+/, Text
+        rule %r/./, Text
       end
 
       state :run do
-        rule /\n/, Text, :pop!
-        rule /\\./m, Str::Escape
+        rule %r/\n/, Text, :pop!
+        rule %r/\\./m, Str::Escape
         rule(/(\\.|[^\n\\])+/) { delegate @shell }
       end
     end
